@@ -32,19 +32,12 @@ pip install cloudcomponents.cdk-codepipeline-slack
 ## How to use
 
 ```python
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { Pipeline, Artifact } from '@aws-cdk/aws-codepipeline';
-import {
-  CodeCommitSourceAction,
-  CodeBuildAction,
-} from '@aws-cdk/aws-codepipeline-actions';
-import { PipelineProject } from '@aws-cdk/aws-codebuild';
-
-import {
-  SlackApprovalAction,
-  SlackNotifier,
-} from '@cloudcomponents/cdk-codepipeline-slack';
+import { SlackApprovalAction, SlackNotifier } from '@cloudcomponents/cdk-codepipeline-slack';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { Pipeline, Artifact } from 'aws-cdk-lib/aws-codepipeline';
+import { CodeCommitSourceAction } from 'aws-cdk-lib/aws-codepipeline-actions';
+import { Construct } from 'constructs';
 
 export class CodePipelineSlackApprovalStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
@@ -62,17 +55,20 @@ export class CodePipelineSlackApprovalStack extends Stack {
       output: sourceArtifact,
     });
 
-    const project = new PipelineProject(this, 'MyProject');
+    if (typeof process.env.SLACK_BOT_TOKEN === 'undefined') {
+      throw new Error('environment variable SLACK_BOT_TOKEN undefined');
+    }
+    const slackBotToken = process.env.SLACK_BOT_TOKEN;
 
-    const buildAction = new CodeBuildAction({
-      actionName: 'CodeBuild',
-      project,
-      input: sourceArtifact,
-    });
+    if (typeof process.env.SLACK_SIGNING_SECRET === 'undefined') {
+      throw new Error('environment variable SLACK_SIGNING_SECRET undefined');
+    }
+    const slackSigningSecret = process.env.SLACK_SIGNING_SECRET;
 
-    const slackBotToken = process.env.SLACK_BOT_TOKEN as string;
-    const slackSigningSecret = process.env.SLACK_SIGNING_SECRET as string;
-    const slackChannel = process.env.SLACK_CHANNEL_NAME as string;
+    if (typeof process.env.SLACK_CHANNEL_NAME === 'undefined') {
+      throw new Error('environment variable SLACK_CHANNEL_NAME undefined');
+    }
+    const slackChannel = process.env.SLACK_CHANNEL_NAME;
 
     const approvalAction = new SlackApprovalAction({
       actionName: 'SlackApproval',
@@ -80,8 +76,7 @@ export class CodePipelineSlackApprovalStack extends Stack {
       slackSigningSecret,
       slackChannel,
       externalEntityLink: 'http://cloudcomponents.org',
-      additionalInformation:
-        'Would you like to promote the build to production?',
+      additionalInformation: 'Would you like to promote the build to production?',
     });
 
     const pipeline = new Pipeline(this, 'MyPipeline', {
@@ -91,10 +86,6 @@ export class CodePipelineSlackApprovalStack extends Stack {
           stageName: 'Source',
           actions: [sourceAction],
         },
-        {
-          stageName: 'Build',
-          actions: [buildAction],
-        },
         {
           stageName: 'Approval',
           actions: [approvalAction],
@@ -158,7 +149,7 @@ import aws_cdk.aws_codepipeline
 import aws_cdk.aws_codepipeline_actions
 import aws_cdk.aws_iam
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 @jsii.enum(jsii_type="@cloudcomponents/cdk-codepipeline-slack.ChannelTypes")
@@ -222,7 +213,7 @@ class SlackApprovalAction(
     @jsii.member(jsii_name="bound")
     def _bound(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         stage: aws_cdk.aws_codepipeline.IStage,
         *,
         bucket: aws_cdk.aws_s3.IBucket,
@@ -409,13 +400,13 @@ class SlackApprovalActionProps(aws_cdk.aws_codepipeline.CommonActionProps):
 
 
 class SlackNotifier(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-codepipeline-slack.SlackNotifier",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         pipeline: aws_cdk.aws_codepipeline.IPipeline,
@@ -457,11 +448,6 @@ class SlackNotifier(
 
     @jsii.member(jsii_name="validate")
     def _validate(self) -> typing.List[builtins.str]:
-        '''Validate the current construct.
-
-        This method can be implemented by derived constructs in order to perform
-        validation logic. It is called on all constructs before synthesis.
-        '''
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "validate", []))
 
     @builtins.property # type: ignore[misc]
